@@ -1,10 +1,9 @@
+import itertools
+
 import dask
 
-from . import registry
 from ..utils import get_ip_interface
-
-
-DEFAULT_SCHEME = dask.config.get("distributed.comm.default-scheme")
+from . import registry
 
 
 def parse_address(addr, strict=False):
@@ -27,7 +26,7 @@ def parse_address(addr, strict=False):
         )
         raise ValueError(msg)
     if not sep:
-        scheme = DEFAULT_SCHEME
+        scheme = dask.config.get("distributed.comm.default-scheme")
     return scheme, loc
 
 
@@ -38,7 +37,7 @@ def unparse_address(scheme, loc):
     >>> unparse_address('tcp', '127.0.0.1')
     'tcp://127.0.0.1'
     """
-    return "%s://%s" % (scheme, loc)
+    return f"{scheme}://{loc}"
 
 
 def normalize_address(addr):
@@ -61,11 +60,11 @@ def parse_host_port(address, default_port=None):
         return address
 
     def _fail():
-        raise ValueError("invalid address %r" % (address,))
+        raise ValueError(f"invalid address {address!r}")
 
     def _default():
         if default_port is None:
-            raise ValueError("missing port number in address %r" % (address,))
+            raise ValueError(f"missing port number in address {address!r}")
         return default_port
 
     if "://" in address:
@@ -100,7 +99,7 @@ def unparse_host_port(host, port=None):
     if ":" in host and not host.startswith("["):
         host = "[%s]" % host
     if port is not None:
-        return "%s:%s" % (host, port)
+        return f"{host}:{port}"
     else:
         return host
 
@@ -121,7 +120,7 @@ def get_address_host_port(addr, strict=False):
         return backend.get_address_host_port(loc)
     except NotImplementedError:
         raise ValueError(
-            "don't know how to extract host and port for address %r" % (addr,)
+            f"don't know how to extract host and port for address {addr!r}"
         )
 
 
@@ -206,6 +205,54 @@ def uri_from_host_port(host_arg, port_arg, default_port):
     return addr
 
 
+def addresses_from_user_args(
+    host=None,
+    port=None,
+    interface=None,
+    protocol=None,
+    peer=None,
+    security=None,
+    default_port=0,
+) -> list:
+    """Get a list of addresses if the inputs are lists
+
+    This is like ``address_from_user_args`` except that it also accepts lists
+    for some of the arguments.  If these arguments are lists then it will map
+    over them accordingly.
+
+    Examples
+    --------
+    >>> addresses_from_user_args(host="127.0.0.1", protocol=["inproc", "tcp"])
+    ["inproc://127.0.0.1:", "tcp://127.0.0.1:"]
+    """
+
+    def listify(obj):
+        if isinstance(obj, (tuple, list)):
+            return obj
+        else:
+            return itertools.repeat(obj)
+
+    if any(isinstance(x, (tuple, list)) for x in (host, port, interface, protocol)):
+        return [
+            address_from_user_args(
+                host=h,
+                port=p,
+                interface=i,
+                protocol=pr,
+                peer=peer,
+                security=security,
+                default_port=default_port,
+            )
+            for h, p, i, pr in zip(*map(listify, (host, port, interface, protocol)))
+        ]
+    else:
+        return [
+            address_from_user_args(
+                host, port, interface, protocol, peer, security, default_port
+            )
+        ]
+
+
 def address_from_user_args(
     host=None,
     port=None,
@@ -214,8 +261,9 @@ def address_from_user_args(
     peer=None,
     security=None,
     default_port=0,
-):
-    """ Get an address to listen on from common user provided arguments """
+) -> str:
+    """Get an address to listen on from common user provided arguments"""
+
     if security and security.require_encryption and not protocol:
         protocol = "tls"
 
@@ -241,7 +289,7 @@ def address_from_user_args(
     else:
         addr = ""
 
-    if protocol and "://" not in addr:
-        addr = protocol.rstrip("://") + "://" + addr
+    if protocol:
+        addr = protocol.rstrip("://") + "://" + addr.split("://")[-1]
 
     return addr
