@@ -5,6 +5,7 @@ import os
 from collections import defaultdict
 from numbers import Number
 
+from bokeh.core.properties import without_property_validation
 from bokeh.io import curdoc
 from bokeh.layouts import column, row
 from bokeh.models import (
@@ -59,13 +60,7 @@ from distributed.dashboard.components.shared import (
     ProfileTimePlot,
     SystemMonitor,
 )
-from distributed.dashboard.utils import (
-    BOKEH_VERSION,
-    PROFILING,
-    transpose,
-    update,
-    without_property_validation,
-)
+from distributed.dashboard.utils import BOKEH_VERSION, PROFILING, transpose, update
 from distributed.diagnostics.graph_layout import GraphLayout
 from distributed.diagnostics.progress_stream import color_of, progress_quads
 from distributed.diagnostics.task_stream import TaskStreamPlugin
@@ -208,7 +203,6 @@ class ProcessingHistogram(DashboardComponent):
             self.root.xaxis.minor_tick_line_alpha = 0
             self.root.ygrid.visible = False
 
-            self.root.toolbar.logo = None
             self.root.toolbar_location = None
 
             self.root.quad(
@@ -232,10 +226,9 @@ def _memory_color(current: int, limit: int) -> str:
     """Dynamic color used by WorkersMemory and ClusterMemory"""
     if limit and current > limit:
         return "red"
-    elif limit and current > limit / 2:
+    if limit and current > limit / 2:
         return "orange"
-    else:
-        return "blue"
+    return "blue"
 
 
 class ClusterMemory(DashboardComponent):
@@ -286,7 +279,6 @@ class ClusterMemory(DashboardComponent):
             self.root.yaxis.visible = False
             self.root.ygrid.visible = False
 
-            self.root.toolbar.logo = None
             self.root.toolbar_location = None
             self.root.yaxis.visible = False
 
@@ -407,7 +399,6 @@ class WorkersMemory(DashboardComponent):
             tap = TapTool(callback=OpenURL(url="./info/worker/@escaped_worker.html"))
             self.root.add_tools(tap)
 
-            self.root.toolbar.logo = None
             self.root.toolbar_location = None
             self.root.yaxis.visible = False
 
@@ -541,7 +532,6 @@ class WorkersMemoryHistogram(DashboardComponent):
             self.root.xaxis.minor_tick_line_alpha = 0
             self.root.ygrid.visible = False
 
-            self.root.toolbar.logo = None
             self.root.toolbar_location = None
 
             self.root.quad(
@@ -605,7 +595,6 @@ class BandwidthTypes(DashboardComponent):
             self.root.xaxis.minor_tick_line_alpha = 0
             self.root.ygrid.visible = False
 
-            self.root.toolbar.logo = None
             self.root.toolbar_location = None
 
             hover = HoverTool()
@@ -622,7 +611,7 @@ class BandwidthTypes(DashboardComponent):
                 "bandwidth": list(bw.values()),
                 "bandwidth-half": [b / 2 for b in bw.values()],
                 "type": list(bw.keys()),
-                "bandwidth_text": list(map(format_bytes, bw.values())),
+                "bandwidth_text": [format_bytes(x) for x in bw.values()],
             }
             self.root.title.text = "Bandwidth: " + format_bytes(
                 self.scheduler.bandwidth
@@ -684,7 +673,6 @@ class BandwidthWorkers(DashboardComponent):
             color_bar.ticker = AdaptiveTicker(**TICKS_1024)
             self.root.add_layout(color_bar, "right")
 
-            self.root.toolbar.logo = None
             self.root.toolbar_location = None
 
             hover = HoverTool()
@@ -712,8 +700,7 @@ class BandwidthWorkers(DashboardComponent):
                     return address
                 if ws.name is not None:
                     return str(ws.name)
-                else:
-                    return address
+                return address
 
             x, y, value = zip(*[(name(a), name(b), c) for (a, b), c in bw.items()])
 
@@ -788,7 +775,6 @@ class ComputePerKey(DashboardComponent):
             fig.xaxis.minor_tick_line_alpha = 0
             fig.xgrid.visible = False
 
-            fig.toolbar.logo = None
             fig.toolbar_location = None
 
             hover = HoverTool()
@@ -956,7 +942,6 @@ class AggregateAction(DashboardComponent):
             self.root.xaxis.minor_tick_line_alpha = 0
             self.root.xgrid.visible = False
 
-            self.root.toolbar.logo = None
             self.root.toolbar_location = None
 
             hover = HoverTool()
@@ -1040,7 +1025,6 @@ class MemoryByKey(DashboardComponent):
             self.root.xaxis.minor_tick_line_alpha = 0
             self.root.ygrid.visible = False
 
-            self.root.toolbar.logo = None
             self.root.toolbar_location = None
 
             hover = HoverTool()
@@ -1147,7 +1131,6 @@ class CurrentLoad(DashboardComponent):
                 )
                 fig.add_tools(tap)
 
-                fig.toolbar.logo = None
                 fig.toolbar_location = None
                 fig.yaxis.visible = False
 
@@ -1167,7 +1150,7 @@ class CurrentLoad(DashboardComponent):
     @without_property_validation
     def update(self):
         with log_errors():
-            workers = list(self.scheduler.workers.values())
+            workers = self.scheduler.workers.values()
             now = time()
             if not any(ws.processing for ws in workers) and now < self.last + 1:
                 return
@@ -2026,8 +2009,7 @@ class TaskGroupGraph(DashboardComponent):
 
         if self.scheduler.transition_counter == self.old_counter:
             return
-        else:
-            self.old_counter = self.scheduler.transition_counter
+        self.old_counter = self.scheduler.transition_counter
 
         if not self.scheduler.task_groups:
             self.subtitle.text = "Scheduler is empty."
